<template>
  <div class="common-card-list" v-change-height:common-card-list-box>
    <div class="common-card-list-box">
      <card-group :class="{ 'common-card-group': !card.hide }" v-for="(card, cardIndex) in cardList" :key="cardIndex">
        <!-- 按钮组 -->
        <template v-slot:content>
          <div class="common-card-item" v-show="!card.hide">
            <!-- 左边 -->
            <div class="common-card-item-left" @click="cardEvent(card.key)">
              <!-- 功能标识 -->
              <div class="common-card-item-left-main">
                <!-- 图标 -->
                <div class="common-card-item-left-main-icon iconfont" :class="`iconfont-${card.icon.key}`" />
                <div class="common-card-item-left-main-text">
                  <!-- 功能名字 -->
                  <p class="common-card-item-left-main-text-name" v-text="card.name" />
                  <!-- 底部文字 -->
                  <p class="common-card-item-left-main-text-footer" v-text="card.footer" />
                </div>
              </div>
              <!-- 当前状态 -->
              <p class="common-card-item-left-describe" :class="{ on: card.icon.type === 'on' }" v-text="card.describe" />
              <gree-icon class="card-arrow" name="arrow-right" size="sm" />
            </div>
          </div>
        </template>
      </card-group>
    </div>
  </div>
</template>

<script>
import { Switch, Icon } from 'gree-ui';
import { glyphs } from '@assets/iconfont/iconfont.json';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';
import { mapMutations, mapState, mapGetters } from 'vuex';
import PopupGroup from '@/components/Popup/index';

export default {
  name: 'common-card',
  components: {
    [Icon.name]: Icon,
    [Switch.name]: Switch,
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup,
    [PopupGroup.name]: PopupGroup
  },
  computed: {
    ...mapState('control', {
      // Mod: state => state.dataObject.Mod,
      // CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      // HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      // HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      // Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18,
      // Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      // HumiEnable: state => state.dataObject.HumiEnable
    }),
    ...mapGetters(['noSwitchCardFuncDefine', 'modTextKey', 'modCurrentStatusName', 'spModCurrentStatusName']),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    cardList() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.noSwitchCardFuncDefine.map(model => {
        const identifier = model.identifier;
        if (!this.statusMap[identifier])
          return {
            icon: {},
            handler: () => {
              console.log('Undefined function');
            }
          };
        // 当前status定义
        const status = this.statusMap[identifier].status;
        // 取名称
        const defaultNameKey = `btn.${identifier}`;
        const footer = this.$language(`footer.${identifier}`);
        // const footer = this.parseStr(footerKey);
        // const describeKey = `describe.${identifier}`;
        // 名称
        const statusNameText = status.name;
        const stateNameText = this.$language(`${identifier}.${statusNameText}`);
        const describe = stateNameText;
        const name = stateNameText === this.$language(stateNameText) ? this.$language(defaultNameKey) : this.$language(stateNameText);
        // 图标
        const icon = glyphs.some(item => item.font_class === status.icon.key) ? status.icon : { key: 'undefined', type: 'off' };
        // 是否隐藏
        const hide = this.blindModelArr.includes(identifier);
        // 执行的方法
        const handler = (identifier, disable = false) => {
          disable || this.$stateMachine.nextStatus(identifier);
        };
        return { key: identifier, name, icon, hide, handler, describe, footer };
      });
      return result;
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    // parseStr(str) {
    //   //  没想好怎么处理，记得改
    //   if (str === 'describe.SvSt') {
    //     const { modText } = this;
    //     const jsonMap = {
    //       1: 'CoolSvStTemMin',
    //       2: 'HumiSvStTemMin',
    //       4: 'HeatSvStTemMax',
    //       6: 'Heat3DSvStTemMax',
    //       7: 'Heat2SvStTemMax'
    //     };
    //     return this.$language(modText) + this.svstTextList + this[jsonMap[this.Mod]] + '℃';
    //   }
    //   return this.$language(str);
    // },
    cardEvent(key) {
      this.SetPopup({ [key + 'Popup']: true });
      console.log(456, [key + 'Popup']);
      key === 'EnergyFlowCard' && this.$router.push('EnergyFlow');
      if (key === 'SmartWind_β') {
        this.SetPopup({ SmartWindPopup: true }); // 两个智能送风功能共用一个popup
        window.$bus.$emit('isSmartWind_β', key);
      }
    }
  }
};
</script>

<style lang="scss">
.common-card-list {
  position: relative;
  margin-right: 15px;
  margin-left: 15px;
  .common-card-group {
    padding-bottom: 40px;
    .common-card-item {
      height: 160px;
      width: 100%;
      display: flex;
      align-items: center;
      justify-content: space-between;
      &-left {
        height: 100%;
        width: 100%;
        display: flex;
        justify-content: space-between;
        align-items: center;
        &-main {
          height: 100%;
          width: 100%;
          margin-left: 20px;
          display: flex;
          justify-content: flex-start;
          align-items: center;
          &-icon {
            $iconHeight: 68px;
            height: $iconHeight;
            width: $iconHeight;
            line-height: $iconHeight;
            margin-left: 42px;
            border-radius: 50%;
            font-size: 40px;
            color: #fff;
            text-align: center;
          }
          .iconfont-Lig,
          .iconfont-AssHt {
            background-image: linear-gradient(to bottom, #fcb28d, #ffac83);
          }
          .iconfont-Air {
            background-image: linear-gradient(to bottom, #8dd6bf, #6ac2a6);
          }
          // .iconfont-wendudanweitubiao-01 {
          //   background-color: #71acf1;
          // }
          .iconfont-zhinengsongfeng,
          .iconfont-wendudanweitubiao-01 {
            background-image: linear-gradient(to bottom, #7fb5f6, #6da4e6);
          }
          .iconfont-disable {
            width: 0;
            opacity: 0;
          }
          &-text {
            padding-left: 20px;
            &-name {
              font-size: 48px;
              color: #404657;
            }
            &-footer {
              font-size: 36px;
              color: #989898;
            }
          }
        }
        &-describe {
          width: 420px;
          font-size: 46px;
          color: #989898;
          text-align: right;
          padding-right: 10px;
          white-space: nowrap;
          &.on {
            color: #71acf1;
          }
        }
        .card-arrow {
          color: #989898;
          padding-right: 50px;
        }
      }
    }
  }
}
</style>
